author = "Kayce Basques"
copyright = f"2025, {author}"
exclude_patterns = []
extensions = []
html_extra_path = []
html_permalinks_icon = "§"
html_static_path = []
project = "sphinx-genai"
pygments_style = "github-dark"
release = "0.0.0"
templates_path = ["_templates"]
